@@ -7,24 +7,24 @@ from telethon import TelegramClient,events
 from telethon import __version__ as telever
 from pyrogram import __version__ as pyrover
 from telethon.tl.types import KeyboardButtonCallback
-from tgtkconsts.ExecVarsSample import ExecVars
-from tgtkcore.getCommand import get_command
-from tgtkcore.getVars import get_val
-from tgtkfunctions.Leech_Module import check_link,cancel_torrent,pause_all,resume_all,purge_all,get_status,print_files, get_transfer
-from tgtkfunctions.tele_upload import upload_a_file,upload_handel
-from tgtkfunctions import Human_Format
-from tgtkcore.database_handle import tkupload,tktorrents, tkdb
-from tgtkcore.settings import handle_settings,handle_setting_callback
-from tgtkcore.user_settings import handle_user_settings, handle_user_setting_callback
+from tgtk.consts.ExecVarsSample import ExecVars
+from tgtk.core.getCommand import get_command
+from tgtk.core.getVars import get_val
+from tgtk.functions.Leech_Module import check_link,cancel_torrent,pause_all,resume_all,purge_all,get_status,print_files, get_transfer
+from tgtk.functions.tele_upload import upload_a_file,upload_handel
+from tgtk.functions import Human_Format
+from tgtk.core.database_handle import tkupload,tktorrents, tkdb
+from tgtk.core.settings import handle_settings,handle_setting_callback
+from tgtk.core.user_settings import handle_user_settings, handle_user_setting_callback
 from functools import partial
-from tgtkfunctions.rclone_upload import get_config, rclone_driver
-from tgtkfunctions.admin_check import is_admin
+from tgtk.functions.rclone_upload import get_config, rclone_driver
+from tgtk.functions.admin_check import is_admin
 from tk import upload_db,var_db,tor_db,user_db, uptime
 import asyncio as aio
 import re,logging,time,os,psutil,shutil
 from tk import __version__
-from tgtkcore.ttk_ytdl import handle_ytdl_command,handle_ytdl_callbacks,handle_ytdl_file_download,handle_ytdl_playlist,handle_ytdl_playlist_down
-from tgtkfunctions.instadl import _insta_post_downloader
+from tgtk.core.ttk_ytdl import handle_ytdl_command,handle_ytdl_callbacks,handle_ytdl_file_download,handle_ytdl_playlist,handle_ytdl_playlist_down
+from tgtk.functions.instadl import _insta_post_downloader
 torlog = logging.getLogger(__name__)
 from .status.status import Status
 from .status.menu import create_status_menu, create_status_user_menu
